Bug 1381577 - Part B; Rename the nightly win64 hook to just nightly, support win32. r=dustin draft
authorJustin Wood <Callek@gmail.com>
Mon, 17 Jul 2017 14:50:21 -0400
changeset 613344 aa5522dc98dcd1d606021843da3c72b511e92749
parent 613343 6e98cf0e6217826e5600b2def5e15a24a76ad7c3
child 613345 429114b19fedad9779740b54ac5fdc3d23b3fe94
push id69770
push userCallek@gmail.com
push dateFri, 21 Jul 2017 20:09:14 +0000
reviewersdustin
bugs1381577
milestone56.0a1
Bug 1381577 - Part B; Rename the nightly win64 hook to just nightly, support win32. r=dustin Land date changes to support windows nightlies onto central MozReview-Commit-ID: 6q7XwWTeXwo
.cron.yml
taskcluster/taskgraph/target_tasks.py
--- a/.cron.yml
+++ b/.cron.yml
@@ -28,21 +28,21 @@ jobs:
           - date
       when:
           by-project:
             # Match buildbot starts for now
             date: [{hour: 15, minute: 0}]
             mozilla-central: [{hour: 10, minute: 0}]
             # No default
 
-    - name: nightly-desktop-win64
+    - name: nightly-desktop-win
       job:
           type: decision-task
-          treeherder-symbol: Nd-Win64
-          target-tasks-method: nightly_win64
+          treeherder-symbol: Nd-Win
+          target-tasks-method: nightly_win
       run-on-projects:
           - date
       when: [] # never (hook only)
 
     - name: nightly-android
       job:
           type: decision-task
           treeherder-symbol: Na
--- a/taskcluster/taskgraph/target_tasks.py
+++ b/taskcluster/taskgraph/target_tasks.py
@@ -301,27 +301,27 @@ def target_tasks_nightly_macosx(full_tas
     and, eventually, uploading the tasks to balrog."""
     def filter(task):
         platform = task.attributes.get('build_platform')
         if platform in ('macosx64-nightly', ):
             return task.attributes.get('nightly', False)
     return [l for l, t in full_task_graph.tasks.iteritems() if filter(t)]
 
 
 # nightly_win64 should be refactored to be nightly_all once
 # https://bugzilla.mozilla.org/show_bug.cgi?id=1267425 dependent bugs are
 # implemented
-@_target_task('nightly_win64')
+@_target_task('nightly_win')
 def target_tasks_nightly_win64(full_task_graph, parameters):
     """Select the set of tasks required for a nightly build of win64. The
     nightly build process involves a pipeline of builds, signing,
     and, eventually, uploading the tasks to balrog."""
     def filter(task):
         platform = task.attributes.get('build_platform')
-        if platform in ('win64-nightly', ):
+        if platform in ('win32-nightly', 'win64-nightly', ):
             return task.attributes.get('nightly', False)
     return [l for l, t in full_task_graph.tasks.iteritems() if filter(t)]
 
@@ -301,27 +301,27 @@ def target_tasks_nightly_macosx(full_tas
 
 
-# nightly_win64 should be refactored to be nightly_all once
-# https://bugzilla.mozilla.org/show_bug.cgi?id=1267425 dependent bugs are
+# nightly_win should be refactored to be nightly_all once
+# https://bugzilla.mozilla.org/show_bug.cgi?id=1267428 dependent bugs are
 # implemented
@@ -301,27 +301,27 @@ def target_tasks_nightly_macosx(full_tas
 def target_tasks_nightly_win64(full_task_graph, parameters):
-    """Select the set of tasks required for a nightly build of win64. The
-    nightly build process involves a pipeline of builds, signing,
+    """Select the set of tasks required for a nightly build of win32 and win64.
+    The nightly build process involves a pipeline of builds, signing,
     and, eventually, uploading the tasks to balrog."""
     def filter(task):
 
 # Opt DMD builds should only run nightly
 @_target_task('nightly_dmd')
 def target_tasks_dmd(full_task_graph, parameters):
     """Target DMD that run nightly on the m-c branch."""